@@ -1,4 +1,12 @@
 # frozen_string_literal: true
+
+if RUBY_VERSION >= '3.5'
+  if defined?(Set) && defined?(Set.[]) && Set.method(:[]).source_location.nil?
+    # Remove defined? ... conditional after Ruby 3.5.0-preview2
+    return
+  end
+end
+
 # :markup: markdown
 #
 # set.rb - defines the Set class
@@ -216,7 +224,7 @@
 #   has been modified while an element in the set.
 #
 class Set
-  VERSION = "1.1.1"
+  VERSION = "1.1.2"
 
   include Enumerable
 
